==> cutemaze_1.2.0.orig.tar.gz: cutemaze-1.2.0/translations/cutemaze_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Promiňte</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Předchozí hru se nepodařilo nahrát. Bude spuštěna nová hra.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 uplynulo</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 kroků učiněno</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1 z %2 cílů zůstává</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Úspěch</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pozastaveno</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Klávesa s oknem</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Příkaz</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Volba</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Vybrat jazyk programu:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Jazyk systému&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Spusťte tento program, prosím, znovu, aby se změna jazyka projevila..</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nová hra</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Lovit a zabít</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Recurzivní zpětné vyhledávání</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Zásobník</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Zásobník 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Zásobník 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Zásobník 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Zásobník 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmus:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Cíle:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Jage und Töte</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Recursive Backtracker</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Zásobník</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Stapel 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Stapel 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Stapel 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Stapel 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>Výsledky</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Výsledek</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Čas</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Kroky</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritmus</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Blahopřání!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>Dostal jste se svým výsledkem mezi nejlepších deset.
Zadejte, prosím, své jméno:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Hra</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Ukázat, kde jste byl</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Ukázat počet učiněných kroků</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Ukázat uplynulý čas</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Hladký pohyb</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Ovládací prvky</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Posunout nahoru:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Posunout dolů:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Posunout vlevo:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Posunout vpravo:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Přepnout značení:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Témata vzhledu</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Vybrat soubor s tématem vzhledu</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Promiňte</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Nepodařilo se vytvořit složku s daty.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Nepodařilo se zkopírovat soubor s tématem vzhledu.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Odstranit vybrané téma vzhledu?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Vybrané téma vzhledu nelze odstranit.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Hra</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nová</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pozastavit</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Rada</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>Nejlepší &amp;výsledky</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>U&amp;končit</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Přiblížit</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Oddálit</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>J&amp;azyk programu...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>Na&amp;stavení...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Nápo&amp;věda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O programu</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Hra odehrávající se v bludišti, při které se pohybujete nahoru, dolů a do stran</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Autorské právo 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Vydáno pod licencí &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Ikony pocházejí z tématu &lt;a href=%1&gt;Oxygen&lt;/a&gt; </translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Použito pod licencí &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> cutemaze_1.2.5.orig.tar.gz: cutemaze-1.2.5/translations/cutemaze_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Promiňte</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Předchozí hru se nepodařilo nahrát. Bude spuštěna nová hra.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 uplynulo</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 kroků učiněno</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1 z %2 cílů zůstává</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Úspěch</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pozastaveno</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Klávesa s oknem</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Příkaz</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Volba</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Vybrat jazyk programu:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Jazyk systému&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Spusťte tento program, prosím, znovu, aby se změna jazyka projevila..</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nová hra</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Lovit a zabít</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Recurzivní zpětné vyhledávání</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Zásobník</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Zásobník 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Zásobník 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Zásobník 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Zásobník 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmus:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Cíle:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Jage und Töte</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Recursive Backtracker</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Zásobník</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Stapel 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Stapel 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Stapel 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Stapel 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>Výsledky</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Výsledek</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Čas</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Kroky</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritmus</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Blahopřání!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>Dostal jste se svým výsledkem mezi nejlepších deset.
Zadejte, prosím, své jméno:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Hra</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Ukázat, kde jste byl</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Ukázat počet učiněných kroků</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Ukázat uplynulý čas</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Hladký pohyb</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Ovládací prvky</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Posunout nahoru:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Posunout dolů:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Posunout vlevo:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Posunout vpravo:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Přepnout značení:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Témata vzhledu</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Vybrat soubor s tématem vzhledu</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Promiňte</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Nepodařilo se vytvořit složku s daty.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Nepodařilo se zkopírovat soubor s tématem vzhledu.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Odstranit vybrané téma vzhledu?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Vybrané téma vzhledu nelze odstranit.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Hra</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nová</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pozastavit</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Rada</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>Nejlepší &amp;výsledky</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>U&amp;končit</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Přiblížit</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Oddálit</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>J&amp;azyk programu...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>Na&amp;stavení...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Nápo&amp;věda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O programu</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Hra odehrávající se v bludišti, při které se pohybujete nahoru, dolů a do stran</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Autorské právo 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Vydáno pod licencí &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Ikony pocházejí z tématu &lt;a href=%1&gt;Oxygen&lt;/a&gt; </translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Použito pod licencí &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>
